@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_SESSIONTHREAD_P_H
-#define KIMAP_SESSIONTHREAD_P_H
+#pragma once
 
 #include <QMutex>
 #include <QQueue>
@@ -88,4 +87,3 @@ private:
 
 }
 
-#endif
